/* -*- Mode: Fundamental -*-
   
   This file is part of Scrunitizer - the C++ Unit Test Framework
   Copyright (C) 2000  Bernd Linowski
   (scrunitizer@linosphere.de)
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or any later version.
   
   This framework is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   

   Version 0.3 / Last changed: 29.08.00
*/


#include <iostream.h>

#include <TestSuite.hh>

#include <qapplication.h>

#include <QScrunitizer.hh>

#include <DemoTest.hh>


int main (int argc, char** argv) {
	QApplication app (argc, argv);

	Scrunitizer::TestManager manager;
	QScrunitizer* scrunitizer = new QScrunitizer ();

	vector<Scrunitizer::Test*> suites;
	suites.push_back (setUpTestSuite ("No problems (fast)", false, false, false, 2));
	suites.push_back (setUpTestSuite ("No problems (slow)", false, false, true, 2));
	suites.push_back (setUpTestSuite ("With failures (fast)", true, false, false, 2));
	suites.push_back (setUpTestSuite ("With failures (slow)", true, false, true, 2));
	suites.push_back (setUpTestSuite ("With errors (fast)", false, true, false, 2));
	suites.push_back (setUpTestSuite ("With errors (slow)", false, true, true, 2));
	suites.push_back (setUpTestSuite ("With failures & errors (fast)", true, true, false, 2));
	suites.push_back (setUpTestSuite ("With failures & errors (slow)", true, true, true, 2));
	suites.push_back (setUpTestSuite ("Stress test (fast, huge)", true, true, false, 50));
	suites.push_back (setUpTestSuite ("Stress test (slow, big)", true, true, true, 20));

	manager.addObserver (scrunitizer);

	instrumentConductor (&manager);
	resetSession (&manager);

	scrunitizer->scrutinize (manager, suites);

	scrunitizer->setCaption ("QScrunitizer: C++ Unit Testing" );
	app.setMainWidget (scrunitizer);
	scrunitizer->show();

	int r = app.exec();

	vector<Scrunitizer::Test*>::iterator pivot;
	for (pivot = suites.begin (); pivot != suites.end (); ++pivot) {
		delete *pivot;
	}

	return r;
}

