/* -*- Mode: Fundamental -*-
   
   This file is part of Scrunitizer - the C++ Unit Test Framework
   Copyright (C) 2000  Bernd Linowski
   (scrunitizer@linosphere.de)
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or any later version.
   
   This framework is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   

   Version 0.3 / Last changed: 29.08.00
*/


#ifndef _QSCRUNITIZER_H_
#define _QSCRUNITIZER_H_

#include <vector>

#include <qlayout.h>
#include <qlabel.h>
#include <qcombobox.h>
#include <qpushbutton.h>
#include <qprogressbar.h>
#include <qlistview.h>
#include <qpixmap.h>

#include <TestObserver.hh>
#include <TestManager.hh>

#include <QXProgressCylinder.hh>


class QScrunitizer : public QWidget, public Scrunitizer::TestObserver {

	Q_OBJECT

	private:
		int				_noTestCases;
		int				_actSuite;
		vector<Scrunitizer::Test*>*	_tests;
		bool				_testing;
		Scrunitizer::TestManager*	_manager;

		QComboBox*		_suiteSelector;
		QPushButton*		_controlButton;
		QPushButton*		_quitButton;
		QXProgressCylinder*	_progressIndicator;
		QLabel*			_okLabel;
		QLabel*			_failedLabel;
		QLabel*			_skippedLabel;
		QLabel*			_failuresLabel;
		QLabel*			_errorsLabel;
		QLabel*			_encounteredLabel;
		QListView*		_logView;

	public:
		QScrunitizer ();
		virtual ~QScrunitizer ();

	public:


		virtual bool configureFrom (Scrunitizer::ArgVector& args);

		virtual bool permitsCancel () const {
			return true;
		}

		virtual void beginSession (Scrunitizer::TestSession& session);
		virtual void endSession (Scrunitizer::TestSession& session, bool cancelled);

		virtual void beginTest (Scrunitizer::Test& test, Scrunitizer::TestSession& session);
		virtual void endTest   (Scrunitizer::Test& test, Scrunitizer::TestSession& session, bool success);
		virtual void testSkipped (Scrunitizer::Test& test, Scrunitizer::TestSession& session);

		virtual void logException (Scrunitizer::TestExceptionRecord& mr, 
					   Scrunitizer::TestSession& session);

		virtual void reset ();

		virtual void scrutinize (Scrunitizer::TestManager& manager, Scrunitizer::Test&);
		virtual void scrutinize (Scrunitizer::TestManager& manager, vector<Scrunitizer::Test*>&);

	public slots:
		void controlTests ();
		void setSuite (int);
};


#endif