/* -*- Mode: Fundamental -*-
   
   This file is part of Scrunitizer - the C++ Unit Test Framework
   Copyright (C) 2000  Bernd Linowski
   (scrunitizer@linosphere.de)
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or any later version.
   
   This framework is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   

   Version 0.3 / Last changed: 30.07.00
*/


#include <iostream>
#include <iomanip>

#include <TestSuite.hh>
#include <BriefSessionLog.hh>
#include <VerboseSessionLog.hh>
#include <ExecutionTracer.hh>
#include <SessionReport.hh>
#include <TestManager.hh>

#include <DemoTest.hh>



int main (int argc, char** argv) {
	Scrunitizer::TestSuite* suite = setUpTestSuite ("Complete feature test suite", true, true, false, 2);

	using namespace Scrunitizer;

	Scrunitizer::TestManager manager;

	Scrunitizer::BriefSessionLog briefLogger (cerr);
	Scrunitizer::VerboseSessionLog verboseLogger (cerr, false);
	Scrunitizer::SessionReport screenReport (cerr, "Xsample Error Report", false);
	Scrunitizer::SessionReport fileReport (cout, "Xsample Error Report", false, false);
	Scrunitizer::ExecutionTracer tracer (manager, cout);

	manager.addObserver (&briefLogger);
	manager.addObserver (&verboseLogger);
	manager.addObserver (&tracer);
	manager.addObserver (&screenReport);
	manager.addObserver (&fileReport);

	ArgVector args (argv, argv + argc);
	try {
		manager.configureFrom (args);
	} 
	catch (LogFileNameMissing& ex) {
		cerr << "ERROR: File name missing after option " << ex.getOptionId () << endl;
		exit (1);
	}
	catch (CannotOpenLog& ex) {
		cerr << "ERROR: Cannot open log file \"" << ex.getFileName () << "\"" << endl;
		exit (1);
	}

	instrumentConductor (&manager);
	resetSession (&manager);

	cerr	<< endl
		<< "******************** Scrunitizer V0.3 Demo ********************" << endl;

	manager.conduct (*suite);

	cerr	<< "************************* End of Demo *************************" << endl
		<< endl;
	cerr	<< "Expected Failures: " << setw (3) << getExpectedFailures ()
		<< "   Handled Failures: " << setw (3) << manager.noFailures ()
		<< "   " << ((getExpectedFailures () == manager.noFailures ()) ? "OK" : "ERROR") << endl;
	cerr	<< "  Expected Errors: " << setw (3) << getExpectedErrors ()
		<< "     Handled Errors: " << setw (3) << manager.noErrors ()
		<< "   " << ((getExpectedErrors () == manager.noErrors ()) ? "OK" : "ERROR") << endl;
	cerr	<< " Expected Skipped: " << setw (3) << getExpectedSkipped ()
		<< "    Handled Skipped: " << setw (3) << manager.noSkipped ()
		<< "   " << ((getExpectedSkipped () == manager.noSkipped ()) ? "OK" : "ERROR") << endl;

	cerr	<< endl
		<< "Demo Status: "
		<< ((getExpectedFailures () == manager.noFailures () &&
		     getExpectedErrors ()   == manager.noErrors ()   &&
		     getExpectedSkipped ()  == manager.noSkipped ()    ) ? 
		    "OK" : "ERROR") << endl 
		<< endl;

	delete suite;

	return 0;
}
