/* -*- Mode: Fundamental -*-
   
   This file is part of Scrunitizer - the C++ Unit Test Framework
   Copyright (C) 2000  Bernd Linowski
   (scrunitizer@linosphere.de)
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or any later version.
   
   This framework is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   

   Version 0.3 / Last changed: 18.08.00
*/


#ifndef _ASSERTIONS_H_
#define _ASSERTIONS_H_


#include <TestExceptions.hh>


namespace Scrunitizer {


template<typename T> 
void _assertCondition (T condition, const string& message, const string& fileName, int line) {
	if (! condition) {
		throw TestFailure (message, fileName, line);
	}
}


template<typename T> 
void _assertEqual (T expected, T actual, const string& message, const string& fileName, int line) {
	if (expected != actual) {
		throw TestFailure (message, fileName, line);
	}
}


template<typename T> 
void _assertApprox (T expected, T actual, T delta, const string& message, const string& fileName,int line) {
	T diff = actual - expected;
	if (diff > delta || diff < - delta) {
		throw TestFailure (message, fileName, line);
	}
}


#ifndef NO_SCRUNIT_ASSERT
#ifdef assert
#undef assert
#endif
#define assert(C,M)		Scrunitizer::_assertCondition ((C), (M), __FILE__, __LINE__)
#endif

#define assertCondition(C,M)	Scrunitizer::_assertCondition ((C), (M), __FILE__, __LINE__)
#define assertEqual(E,A,M)	Scrunitizer::_assertEqual ((E), (A), (M), __FILE__, __LINE__)
#define assertApprox(E,A,D,M)	Scrunitizer::_assertApprox ((E), (A), (D), (M), __FILE__, __LINE__)


} // End of namespace Scrunitizer

#endif
