/* -*- Mode: Fundamental -*-
   
   This file is part of Scrunitizer - the C++ Unit Test Framework
   Copyright (C) 2000  Bernd Linowski
   (scrunitizer@linosphere.de)
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or any later version.
   
   This framework is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   

   Version 0.3 / Last changed: 02.07.00
*/


#include <StreamingObserver.hh>


namespace Scrunitizer {


StreamingObserver::StreamingObserver (
	ostream& log,
	bool enabled,
	bool permitCancel
) : _enabled (enabled), _permitCancel (permitCancel), _log (&log), _file (0) { 
}


StreamingObserver::~StreamingObserver () {
	if (_file) _file->close ();
}


bool StreamingObserver::configureFrom (ArgVector& args) {
	_options.apply (*this, args);
	return _enabled;
}


void StreamingObserver::enabled (bool state) {
	_enabled = state;
}


void StreamingObserver::permitCancel (bool state) {
	_permitCancel = state;
}


void StreamingObserver::setLog (ostream& log) {
	if (_file) _file->close ();
	_log  = &log;
	_file = 0;
}


void StreamingObserver::setLog (const string& filename) {
	if (_file) _file->close ();

	_file = new ofstream (filename.c_str ());
	if (! *_file) {
		_file = 0;
		throw CannotOpenLog (filename);
	}

	_log = _file;
}



LogFileOption::LogFileOption (
	StreamingObserver& observer,
	const string& id,
	bool autoEnable,
	bool consuming
) : OptionHandler<StreamingObserver> (id, consuming), _observer (observer), _autoEnable (autoEnable) {
}


LogFileOption::~LogFileOption () {
}


ArgVector::iterator LogFileOption::fireOption (
	StreamingObserver& inst, 
	const string& id, 
	ArgVector& args, 
	ArgVector::iterator rest
) {
	if (rest == args.end () || (*rest)[0] == '-') {
		throw LogFileNameMissing (id);
	}
	_observer.setLog (*rest);
	_observer.enabled (true);

	return args.erase (rest);
}


} // End of namespace Scrunitizer

