/* -*- Mode: Fundamental -*-
   
   This file is part of Scrunitizer - the C++ Unit Test Framework
   Copyright (C) 2000  Bernd Linowski
   (scrunitizer@linosphere.de)
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or any later version.
   
   This framework is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   

   Version 0.3 / Last changed: 30.07.00
*/

#ifndef _TEST_DECORATOR_H_
#define _TEST_DECORATOR_H_


#include <Test.hh>


namespace Scrunitizer {


//: Decorator for test objects.
// All operations are delegated to the shadowed test object. 
// This class could be used as base class for classes
// that add or modify test functionality by wrapping the
// another test object that implements the basic functionality.
// This class is intended to be subsclassed by "real decorators".
//
class TestDecorator : public TestWrapper {

	protected:
		//: Create a decorator for the given test object.
		// The decorator wraps the test object and adds additional functionality. 
		// By default, it is assumed that the shadowed test is owned
		// by the decorator. Therefore, the default value for <TT>release</TT> is true.
		//
		TestDecorator (
			const string& name,
			Test* test, 
			bool release = true
		) : TestWrapper (name, test, release) {
		}

};


} // End of namespace Scrunitizer

#endif
