/* -*- Mode: Fundamental -*-
   
   This file is part of Scrunitizer - the C++ Unit Test Framework
   Copyright (C) 2000  Bernd Linowski
   (scrunitizer@linosphere.de)
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or any later version.
   
   This framework is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   

   Version  / Last changed: 09.08.00
*/


#include <cstring>

#include <TestExceptions.hh>


namespace Scrunitizer {


TestException::ExceptionInfo::ExceptionInfo (
	const string& message,
	const string& fileName,
	int line
) : _refCount (1), _message (message), _fileName (fileName), _line (line) {
}


TestException::ExceptionInfo::~ExceptionInfo () {
}


TestException::TestException (
	const string& message,
	const string& fileName,
	int line
) {
	_body = new ExceptionInfo (message, fileName, line);
}


TestException::TestException (const TestException& te) {
	_body = te._body;
	_body->_refCount++;
}


TestException::~TestException () {
	if (--_body->_refCount == 0) {
		delete _body;
	}
}

TestException& TestException::operator= (const TestException& rhs) {
	if (&rhs == this) return *this;

	if (--_body->_refCount == 0) {
		delete _body;
	}
	_body = rhs._body;
	_body->_refCount++;

	return *this;
}


} // End of namespace Scrunitizer

