/* -*- Mode: Fundamental -*-
   
   This file is part of Scrunitizer - the C++ Unit Test Framework
   Copyright (C) 2000  Bernd Linowski
   (scrunitizer@linosphere.de)
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or any later version.
   
   This framework is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   

   Version 0.3 / Last changed: 19.08.00
*/

#ifndef _TEST_PROXY_H_
#define _TEST_PROXY_H_


#include <TestWrapper.hh>


namespace Scrunitizer {


//: Proxy for test objects.
// Objects of this class delegate all operations to
// the shadowed test object. One major use-case for this class
// is to refer to a test that <I>is already owned by another test suite</I>.
//
class TestProxy : public TestWrapper {

	public:
		//: Create a proxy for the given test object.
		// The proxy shadows the test object. 
		// It is assumed that the shadowed test is owned
		// by another object, so it is <I>not</I> deleted when the proxy
		// is destroyed.
		//
		TestProxy (
			const string& name,
			Test* test
		) : TestWrapper (name, test, false) {
		}

		//: Create a proxy for the given test object.
		// Like above, but with no specific name, so "Proxy" is used instead.
		//
		TestProxy (
			Test* test
		) : TestWrapper ("Proxy", test, false) {
		}

		//: Copy constructor.
		// Name and shadowed test are copied.
		//
		TestProxy (
			const TestProxy& src
		) : TestWrapper (src.getName (), src.getTestObject (), false) {
		}

		//: Assignment operator.
		// Only the target object is copied!. The name of the proxy stays
		// unchanged. This allows target redirection without renaming the
		// proxy itself. If an exact copy is needed, a new object could be 
		// created.
		//
		TestProxy& operator= (const TestProxy& rhs) {
			setTestObject (rhs.getTestObject ());
			return *this;
		}

};



} // End of namespace Scrunitizer

#endif
