/* -*- Mode: Fundamental -*-
   
   This file is part of Scrunitizer - the C++ Unit Test Framework
   Copyright (C) 2000  Bernd Linowski
   (scrunitizer@linosphere.de)
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or any later version.
   
   This framework is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   

   Version 0.3 / Last changed: 09.08.00
*/


#include <TestRepeater.hh>


namespace Scrunitizer {


TestRepeater::TestRepeater (
	const string& name, 
	int repetitions, 
	Test* test,
	bool breakOnFailure // = false
) : Test (name), _test (test), _repetitions (repetitions), _breakOnFailure (breakOnFailure) {
	if (test == 0 || repetitions < 0) {
		throw IllegalTestSetUp ();
	}
}



TestRepeater::~TestRepeater () {
	delete _test;
}


bool TestRepeater::run (TestConductor& conductor) {
	conductor.execute (*this);
	return _success;
}


void TestRepeater::test (TestConductor& conductor) {
	int i;
	_success = true;
	for (i = 0; i < _repetitions; ++i) {
		if (! _test->run (conductor)) {
			_success = false;
			if (_breakOnFailure) {
				++i;
				break;
			}
		}
	}
	for (; i < _repetitions; ++i) {
		conductor.skip (*_test);
	}
}


int TestRepeater::noTestCases () const {
	return _repetitions * _test->noTestCases ();
}


int TestRepeater::noTestSuites () const {
	return _repetitions * _test->noTestSuites () + 1;
}


} // End of namespace Scrunitizer

