/* -*- Mode: Fundamental -*-
   
   This file is part of Scrunitizer - the C++ Unit Test Framework
   Copyright (C) 2000  Bernd Linowski
   (scrunitizer@linosphere.de)
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or any later version.
   
   This framework is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   

   Version 0.3 / Last changed: 15.07.00
*/


#include <TestSuite.hh>


namespace Scrunitizer {


TestSuite::TestSuite (
	const string& name,
	bool breakOnFailure // = false;
) : Test (name), _breakOnFailure (breakOnFailure) {
}


TestSuite::~TestSuite () {
	vector<Test*>::iterator pivot;
	for (pivot = _tests.begin (); pivot != _tests.end (); ++pivot) {
		delete *pivot;
	}
}


bool TestSuite::run (
	TestConductor& conductor
) {
	conductor.execute (*this);

	return _success;
}


void TestSuite::test (TestConductor& conductor) {
	_success = true;
	vector<Test*>::iterator pivot;
	for (pivot = _tests.begin (); pivot != _tests.end (); ++pivot) {
		if (! (*pivot)->run (conductor)) {
			_success = false;
			if (_breakOnFailure) {
				++pivot; 
				break;
			}
		}
	}
	for (; pivot != _tests.end (); ++pivot) {
		conductor.skip (**pivot);
	}
}


bool TestSuite::isTestCase () const {
	return false;
}


int TestSuite::noTestCases () const {
	vector<Test*>::const_iterator pivot;
	int sum = 0;
	for (pivot = _tests.begin (); pivot != _tests.end (); ++pivot) {
		sum += (*pivot)->noTestCases ();
	}

	return sum;
}


int TestSuite::noTestSuites () const {
	vector<Test*>::const_iterator pivot;
	int sum = 1;
	for (pivot = _tests.begin (); pivot != _tests.end (); ++pivot) {
		sum += (*pivot)->noTestSuites ();
	}

	return sum;
}


void TestSuite::add (
	Test* test
) {
	if (test == 0) {
		throw IllegalTestSetUp ();
	}

	_tests.push_back (test);
}


} // End of namespace Scrunitizer
